summaryrefslogtreecommitdiff
path: root/django/db/backends/base/features.py
diff options
context:
space:
mode:
Diffstat (limited to 'django/db/backends/base/features.py')
-rw-r--r--django/db/backends/base/features.py5
1 files changed, 3 insertions, 2 deletions
diff --git a/django/db/backends/base/features.py b/django/db/backends/base/features.py
index bb4b59e7c8..70878f92a2 100644
--- a/django/db/backends/base/features.py
+++ b/django/db/backends/base/features.py
@@ -143,9 +143,10 @@ class BaseDatabaseFeatures:
# Can the backend introspect a TimeField, instead of a DateTimeField?
can_introspect_time_field = True
# Some backends may not be able to differentiate BigAutoField from other
# fields such as AutoField.
introspected_big_auto_field_type = 'BigAutoField'
+ introspected_small_auto_field_type = 'SmallAutoField'
# Some backends may not be able to differentiate BooleanField from other
# fields such as IntegerField.
@@ -143,9 +143,10 @@ class BaseDatabaseFeatures:
# Can the backend introspect a TimeField, instead of a DateTimeField?
can_introspect_time_field = True
- # Some backends may not be able to differentiate BigAutoField from other
- # fields such as AutoField.
+ # Some backends may not be able to differentiate BigAutoField or
+ # SmallAutoField from other fields such as AutoField.
introspected_big_auto_field_type = 'BigAutoField'